@@ -19,5 +19,8 @@ setup(name='elisa-plugin-base',
     packages=packages,
     package_dir=package_dir,
     package_data={'': ['*.png', '*.mo', '*.po']},
-    entry_points="",
+    entry_points="""
+    [elisa.core.components.resource_provider]
+    LocalResource = elisa.plugins.base.local_resource:LocalResource
+    """,
     cmdclass=cmdclass)
