@@ -18,5 +18,7 @@ setup(name='elisa-plugin-gnome',
     package_dir=package_dir,
     package_data={'': ['*.png', '*.mo', '*.po']},
     entry_points="""\
+    [elisa.core.components.service_provider]
+    GnomeScreensaverService = elisa.plugins.gnome.gnome_screensaver_service:GnomeScreensaverService
     """,
     cmdclass=cmdclass)
